;    ******************************************************************
;    *        Sample LIAL program to compute Fibonacci numbers        *
;    ******************************************************************
 
;******************************** REMARKS ***********************************
;
; This program finds the largest Fibonacci number that fits the declared
; long integer size (N).  Fibonacci numbers are defined as follows:
;
;               1.  F(0) = 0 and F(1) = 1
;               2.  For n > 1, F(n) = F(n - 1) + F(n - 2)
;
;************************* ASSEMBLER ASSIGNMENTS ****************************
 
; First, initialize some header values:
 
* PC      = BOOT   ; initialize program counter (default also ok here)
* N       = 64     ; number of bytes per long integer
* STORAGE = 192    ; at least three times N
* FLAGS   = $7     ; enables user break, program & storage bounds checking
 
; Next, assign variable names to lowest available long integers (0-15):
 
# FIB     = 0      ; needed for old previous addition result
# TEMP    = 1      ; save area for intermediate conversion result
 
;****************************** PROGRAM *************************************
 
BOOT   ZER
       STA FIB     ; put first Fibonacci number (0) into FIB
       INC         ; put second Fibonacci number (1) into accumulator
LOOP   EXA FIB
       ADD FIB     ; next Fibonacci number is sum of previous two
       BVC LOOP    ; branch if overflow is clear
       ZER
       EXA FIB
       END         ; ...of Fibonacci computation
 
; At this point, first N storage bytes holds binary value of largest Fibonnaci
; number that fits into N bytes.  Display storage for peek, then restart
; program for following conversion to packed decimal.
 
       BDI         ; first call puts low order digits into FIB
       EXA FIB
       STA TEMP    ; save low order digits
       LDA FIB
       BDI         ; second call puts remaining leading digits into FIB
       EXA TEMP    ; move result into first 2 * N bytes with two exchange
       EXA FIB     ;   instructions
       END
       BRN BOOT    ; ...included to prevent bounds error on restart
 
; Now, first 2 * N bytes hold packed-decimal Fibonacci number, right adjusted.
; Display storage for peek.
 
;****************************** END PROGRAM *********************************
